<?php

	include_once( PLOG_CLASS_PATH."class/action/admin/adminaction.class.php" );
	include_once( PLOG_CLASS_PATH."class/view/admin/adminregisterblogview.class.php" );
	include_once( PLOG_CLASS_PATH."class/view/admin/admindashboardview.class.php" );	
	include_once( PLOG_CLASS_PATH."class/data/validator/stringvalidator.class.php" );
    include_once( PLOG_CLASS_PATH."class/data/validator/domainvalidator.class.php" );	
	include_once( PLOG_CLASS_PATH."class/dao/blogs.class.php" );
	include_once( PLOG_CLASS_PATH."class/dao/users.class.php" );
	include_once( PLOG_CLASS_PATH."class/dao/articles.class.php" );	
	include_once( PLOG_CLASS_PATH."class/dao/articlecategories.class.php" );
	include_once( PLOG_CLASS_PATH."class/data/timestamp.class.php" );
	include_once( PLOG_CLASS_PATH."class/net/http/subdomains.class.php" );
	
	class AdminDoRegisterBlogAction extends AdminAction
	{
	
		function AdminDoRegisterBlogAction( $actionInfo, $request )
		{
			$this->AdminAction( $actionInfo, $request );
			
			$this->registerFieldValidator( "blogName", new StringValidator());
            $this->registerFieldValidator( "blogSubDomain", new DomainValidator(), true );
            $this->registerFieldValidator( "blogMainDomain", new DomainValidator(), true );
            $this->registerFieldValidator( "blogLocale", new StringValidator());
			$this->registerFieldValidator( "templateId", new StringValidator());
			$this->setValidationErrorView( new AdminRegisterBlogView( $this->_userInfo ));
		}
		
		function perform()
		{
			// if the validation of data went fine, then we can proceed and add the blog
			$localeCode = $this->_request->getValue( "localeId" );
			$template = $this->_request->getValue( "templateId" );
			$name = $this->_request->getValue( "blogName" );
			
			// create the blog...
			$blog = new BlogInfo( $name, $this->_userInfo->getId(),  // owner id
			                      '',  // about
			                      '');  // settings

            // check to see whether we are going to save subdomain information			
            if( Subdomains::getSubdomainsEnabled()) {
                // Translate a few characters to valid names, and remove the rest
                $mainDomain = Textfilter::domainize($this->_request->getValue( "blogMainDomain" ));
                if(!$mainDomain)
					$mainDomain = "?";
                $subDomain = Textfilter::domainize($this->_request->getValue( "blogSubDomain" ));

                if(!Subdomains::isDomainAvailable($mainDomain)){
                    $this->_view = new AdminRegisterBlogView( $this->_userInfo );
                    $this->_view->setErrorMessage( $this->_locale->tr("error_updating_blog_subdomain"));
                    $this->setCommonData();
                    return false;
                }

				if(!Subdomains::isValidDomainName($subDomain)){
	                $this->_view = new AdminRegisterBlogView( $this->_userInfo );
	                $this->_view->setErrorMessage( $this->_locale->tr("error_updating_blog_subdomain"));
	                $this->setCommonData();
	                return false;
				}

                if($mainDomain == "?"){
					$blog_domain = $subDomain;
                }
                else{
					$blog_domain = $subDomain . "." . $mainDomain;
                }

				$blog->setCustomDomain( $blog_domain );
            }			

                // set the template
			$blog->setTemplate( $template );
			// set the locale
			$locale = Locales::getLocale( $localeCode );
			$blog->setLocale( $locale );
			// and set the status to ready
			$blog->setStatus( BLOG_STATUS_ACTIVE );
			
			// and finally add everything to the db
			$blogs = new Blogs();
			if( !$blogs->addBlog( $blog )) {
				$this->_view = new AdminRegisterBlogView( $this->_userInfo );
				$this->setCommonData( true );
			}
			
			$newBlogId = $blog->getId();
            $articleCategories = new ArticleCategories();
            $articleCategory = new ArticleCategory( "General", "", $newBlogId, true );
            $catId = $articleCategories->addArticleCategory( $articleCategory );
            $articleTopic = $locale->tr( "register_default_article_topic" );
            $articleText  = $locale->tr( "register_default_article_text" );
            $article = new Article( $articleTopic, 
                                    $articleText, 
                                    Array( $catId ), 
                                    $this->_userInfo->getId(), 
                                    $newBlogId, 
                                    POST_STATUS_PUBLISHED, 
                                    0, 
                                    Array(), 
                                    "welcome" );
            $t = new Timestamp();
            $article->setDateObject( $t );
            $articles = new Articles();
            $articles->addArticle( $article );	           
						
			// redirect process to the dashboard view
			$users = new Users();
			$usersBlogs = $users->getUsersBlogs( $this->_userInfo->getId(), BLOG_STATUS_ACTIVE );
			$this->_view = new AdminDashboardView( $this->_userInfo, $usersBlogs ); 
		}
	}
?>